@@ -10,25 +10,25 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.04';
-$DATE = '2004/05/03';
+$VERSION = '0.05';
+$DATE = '2004/05/13';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_SmartNL.pm' => [qw(0.04 2004/05/03), 'revised 0.03'],
-    'MANIFEST' => [qw(0.04 2004/05/03), 'generated, replaces 0.03'],
-    'Makefile.PL' => [qw(0.04 2004/05/03), 'generated, replaces 0.03'],
-    'README' => [qw(0.04 2004/05/03), 'generated, replaces 0.03'],
-    'lib/File/SmartNL.pm' => [qw(1.14 2004/05/03), 'revised 1.1'],
-    't/File/SmartNL.d' => [qw(0.01 2004/05/03), 'new'],
-    't/File/SmartNL.pm' => [qw(0.01 2004/05/03), 'new'],
-    't/File/SmartNL.t' => [qw(0.1 2004/05/03), 'revised 0.09'],
-    't/File/File/Package.pm' => [qw(1.16 2004/05/03), 'new'],
-    't/File/Test/Tech.pm' => [qw(1.22 2004/05/03), 'new'],
-    't/File/Data/Secs2.pm' => [qw(1.19 2004/05/03), 'new'],
-    't/File/Data/SecsPack.pm' => [qw(0.04 2004/05/03), 'new'],
-    't/File/Data/Startup.pm' => [qw(0.04 2004/05/03), 'new'],
+    'lib/Docs/Site_SVD/File_SmartNL.pm' => [qw(0.05 2004/05/13), 'revised 0.04'],
+    'MANIFEST' => [qw(0.05 2004/05/13), 'generated, replaces 0.04'],
+    'Makefile.PL' => [qw(0.05 2004/05/13), 'generated, replaces 0.04'],
+    'README' => [qw(0.05 2004/05/13), 'generated, replaces 0.04'],
+    'lib/File/SmartNL.pm' => [qw(1.16 2004/05/13), 'revised 1.14'],
+    't/File/SmartNL.d' => [qw(0.01 2004/05/03), 'unchanged'],
+    't/File/SmartNL.pm' => [qw(0.01 2004/05/03), 'unchanged'],
+    't/File/SmartNL.t' => [qw(0.11 2004/05/13), 'revised 0.1'],
+    't/File/File/Package.pm' => [qw(1.17 2004/05/13), 'revised 1.16'],
+    't/File/Test/Tech.pm' => [qw(1.25 2004/05/13), 'revised 1.22'],
+    't/File/Data/Secs2.pm' => [qw(1.23 2004/05/13), 'revised 1.19'],
+    't/File/Data/SecsPack.pm' => [qw(0.08 2004/05/13), 'revised 0.04'],
+    't/File/Data/Startup.pm' => [qw(0.06 2004/05/13), 'revised 0.04'],
 
 );
 
@@ -47,19 +47,23 @@ use vars qw(%INVENTORY);
 
 
 
+=head1 NAME
+
+Docs::Site_SVD::File_SmartNL - translates any combination of CR and NL to the site \nl
+
 =head1 Title Page
 
  Software Version Description
 
  for
 
-  File::SmartNL - translates any combination of CR and NL to the site \nl
+ Docs::Site_SVD::File_SmartNL - translates any combination of CR and NL to the site \nl
 
- Revision: C
+ Revision: D
 
- Version: 0.04
+ Version: 0.05
 
- Date: 2004/05/03
+ Date: 2004/05/13
 
  Prepared for: General Public 
 
@@ -132,7 +136,7 @@ that have not upgraded to Perl 5.6.
 
 =head2 1.3 Document overview.
 
-This document releases File::SmartNL version 0.04
+This document releases File::SmartNL version 0.05
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -147,7 +151,7 @@ system file specification.
 
 This document releases the file 
 
- File-SmartNL-0.04.tar.gz
+ File-SmartNL-0.05.tar.gz
 
 found at the following repository(s):
 
@@ -191,6 +195,20 @@ disclaimer in the documentation and/or
 other materials provided with the
 distribution.
 
+=item 3
+
+Commercial installation of the binary or source
+must visually present to the installer 
+the above copyright notice,
+this list of conditions intact,
+that the original source is available
+at http://softwarediamonds.com
+and provide means
+for the installer to actively accept
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
 =back
 
 SOFTWARE DIAMONDS, http://www.SoftwareDiamonds.com,
@@ -219,19 +237,19 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_SmartNL.pm                            0.04    2004/05/03 revised 0.03
- MANIFEST                                                     0.04    2004/05/03 generated, replaces 0.03
- Makefile.PL                                                  0.04    2004/05/03 generated, replaces 0.03
- README                                                       0.04    2004/05/03 generated, replaces 0.03
- lib/File/SmartNL.pm                                          1.14    2004/05/03 revised 1.1
- t/File/SmartNL.d                                             0.01    2004/05/03 new
- t/File/SmartNL.pm                                            0.01    2004/05/03 new
- t/File/SmartNL.t                                             0.1     2004/05/03 revised 0.09
- t/File/File/Package.pm                                       1.16    2004/05/03 new
- t/File/Test/Tech.pm                                          1.22    2004/05/03 new
- t/File/Data/Secs2.pm                                         1.19    2004/05/03 new
- t/File/Data/SecsPack.pm                                      0.04    2004/05/03 new
- t/File/Data/Startup.pm                                       0.04    2004/05/03 new
+ lib/Docs/Site_SVD/File_SmartNL.pm                            0.05    2004/05/13 revised 0.04
+ MANIFEST                                                     0.05    2004/05/13 generated, replaces 0.04
+ Makefile.PL                                                  0.05    2004/05/13 generated, replaces 0.04
+ README                                                       0.05    2004/05/13 generated, replaces 0.04
+ lib/File/SmartNL.pm                                          1.16    2004/05/13 revised 1.14
+ t/File/SmartNL.d                                             0.01    2004/05/03 unchanged
+ t/File/SmartNL.pm                                            0.01    2004/05/03 unchanged
+ t/File/SmartNL.t                                             0.11    2004/05/13 revised 0.1
+ t/File/File/Package.pm                                       1.17    2004/05/13 revised 1.16
+ t/File/Test/Tech.pm                                          1.25    2004/05/13 revised 1.22
+ t/File/Data/Secs2.pm                                         1.23    2004/05/13 revised 1.19
+ t/File/Data/SecsPack.pm                                      0.08    2004/05/13 revised 0.04
+ t/File/Data/Startup.pm                                       0.06    2004/05/13 revised 0.04
 
 
 =head2 3.3 Changes
@@ -326,10 +344,10 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
  for
 
 
-  File::SmartNL - translates any combination of CR and NL to the site \nl
+ Docs::Site_SVD::File_SmartNL - translates any combination of CR and NL to the site \nl
 
 
- Revision: C
+ Revision: D
 
 [snip]
 
@@ -344,7 +362,7 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
  for
 
 
-  File::SmartNL - translates any combination of CR and NL to the site \nl
+ Docs::Site_SVD::File_SmartNL - translates any combination of CR and NL to the site \nl
 
 What we have before, was a totally "failure to communicate." aka Cool Hand Luke. 
 VAR1 was empty. Now VAR1 has something. It is not completely dead.
@@ -480,6 +498,12 @@ Added better option support by using the C<Data::Startup> program module.
 
 Added a subroutine interface.
 
+=item File-SmartNL-0.05
+
+Better test for a file handle. Do not close a file handle.
+
+Changed C<$options->warn>, function, to C<$options->{warn}>, a value.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -518,13 +542,13 @@ Enter one of the following repositories in a web browser:
   http://www.softwarediamonds/packages/
   http://www.perl.com/CPAN/authors/id/S/SO/SOFTDIA/
 
-Right click on 'File-SmartNL-0.04.tar.gz' and download to a temporary
+Right click on 'File-SmartNL-0.05.tar.gz' and download to a temporary
 installation directory.
 Enter the following where $make is 'nmake' for microsoft
 windows; otherwise 'make'.
 
- gunzip File-SmartNL-0.04.tar.gz
- tar -xf File-SmartNL-0.04.tar
+ gunzip File-SmartNL-0.05.tar.gz
+ tar -xf File-SmartNL-0.05.tar
  perl Makefile.PL
  $make test
  $make install
@@ -631,15 +655,15 @@ __DATA__
 DISTNAME: File-SmartNL^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.04^
+VERSION : 0.05^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.03^
-REVISION: C^
+PREVIOUS_RELEASE: 0.04^
+REVISION: D^
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: translates any combination of CR and NL to the site \nl^
-TITLE   :  File::SmartNL - translates any combination of CR and NL to the site \nl^
+TITLE   : Docs::Site_SVD::File_SmartNL - translates any combination of CR and NL to the site \nl^
 END_USER: General Public^
 COPYRIGHT: copyright  2003 Software Diamonds^
 CLASSIFICATION: NONE^
@@ -919,6 +943,12 @@ Added better option support by using the C<Data::Startup> program module.
 
 Added a subroutine interface.
 
+\=item File-SmartNL-0.05
+
+Better test for a file handle. Do not close a file handle.
+
+Changed C<$options->warn>, function, to C<$options->{warn}>, a value.
+
 \=back
 
 ^
@@ -1028,6 +1058,20 @@ disclaimer in the documentation and/or
 other materials provided with the
 distribution.
 
+\=item 3
+
+Commercial installation of the binary or source
+must visually present to the installer 
+the above copyright notice,
+this list of conditions intact,
+that the original source is available
+at http://softwarediamonds.com
+and provide means
+for the installer to actively accept
+the list of conditions; 
+otherwise, a license fee must be paid to
+Softwareware Diamonds.
+
 \=back
 
 SOFTWARE DIAMONDS, http://www.SoftwareDiamonds.com,
@@ -1127,3 +1171,5 @@ HTML:
 ~-~
 
 
+
+
